import hashlib
import binascii
from z3 import *


def bruteforce(func, expected):
    result = bytearray(2)
    for i in range(0x10000):
        result[0] = i & 0xFF
        result[1] = (i >> 8) & 0xFF
        if func(result) == expected:
            return result
    return None

crc1 = bruteforce(binascii.crc32, 0x61089c5c)
crc2 = bruteforce(binascii.crc32, 0x5888fc1b)
crc3 = bruteforce(binascii.crc32, 0x66715919)
crc4 = bruteforce(binascii.crc32, 0x7cab8d64)

sha1 = bruteforce(lambda x: hashlib.sha256(x).hexdigest(), "403d5f23d149670348b147a15eeb7010914701a7e99aad2e43f90cfa0325c76f")
sha2 = bruteforce(lambda x: hashlib.sha256(x).hexdigest(), "593f2d04aab251f60c9e4b8bbc1e05a34e920980ec08351a18459b2bc7dbf2f6")

md1 = bruteforce(lambda x: hashlib.md5(x).hexdigest(), "89484b14b36a8d5329426a3d944d2983")
md2 = bruteforce(lambda x: hashlib.md5(x).hexdigest(), "f98ed07a4d5f50f7de1410d905f1477f")
md3 = bruteforce(lambda x: hashlib.md5(x).hexdigest(), "657dae0913ee12be6fb2a6f687aae1c7")
md4 = bruteforce(lambda x: hashlib.md5(x).hexdigest(), "738a656e8e8ec272ca17cd51e12f558b")


filesize = 85

data = [BitVec(f"b{i}", 85 * 8) for i in range(filesize)]

s = Solver()

s.add(data[8] == crc1[0])
s.add(data[9] == crc1[1])

s.add(data[34] == crc2[0])
s.add(data[35] == crc2[1])

s.add(data[63] == crc3[0])
s.add(data[64] == crc3[1])

s.add(data[78] == crc4[0])
s.add(data[79] == crc4[1])

s.add(data[14] == sha1[0])
s.add(data[15] == sha1[1])

s.add(data[56] == sha2[0])
s.add(data[57] == sha2[1])

s.add(data[0] == md1[0])
s.add(data[1] == md1[1])

s.add(data[76] == md2[0])
s.add(data[77] == md2[1])

s.add(data[50] == md3[0])
s.add(data[51] == md3[1])

s.add(data[32] == md4[0])
s.add(data[33] == md4[1])

s.add(filesize ^ data[11] != 107)
s.add(data[55] & 128 == 0)
s.add(data[58] + 25 == 122)
s.add(data[7] & 128 == 0)
s.add(data[48] % 12 < 12)
s.add(data[17] > 31)
s.add(data[68] > 10)
s.add(data[56] < 155)
s.add((data[52] | (data[52+1] << 8) | (data[52+2] << 16) | (data[52+3] << 24)) ^ 425706662 == 1495724241)
s.add(data[0] % 25 < 25)
s.add(filesize ^ data[75] != 25)
s.add(filesize ^ data[28] != 12)
s.add(data[35] < 160)
s.add(data[3] & 128 == 0)
s.add(data[56] & 128 == 0)
s.add(data[28] % 27 < 27)
s.add(data[4] > 30)
s.add(data[15] & 128 == 0)
s.add(data[68] % 19 < 19)
s.add(data[19] < 151)
s.add(filesize ^ data[73] != 17)
s.add(filesize ^ data[31] != 5)
s.add(data[38] % 24 < 24)
s.add(data[3] > 21)
s.add(data[54] & 128 == 0)
s.add(filesize ^ data[66] != 146)
s.add((data[17] | (data[17+1] << 8) | (data[17+2] << 16) | (data[17+3] << 24)) - 323157430 == 1412131772)
s.add(filesize ^ data[77] != 22)
s.add(data[75] % 24 < 24)
s.add(data[66] < 133)
s.add(data[21] % 11 < 11)
s.add(data[46] < 154)
s.add(data[55] > 5)
s.add(data[36] + 4 == 72)
s.add(filesize ^ data[82] != 228)
s.add(filesize ^ data[13] != 42)
s.add(filesize ^ data[6] != 39)
s.add(data[33] < 160)
s.add(filesize ^ data[55] != 244)
s.add(filesize ^ data[15] != 205)
s.add(filesize ^ data[3] != 43)
s.add(filesize ^ data[54] != 39)
s.add(data[28] & 128 == 0)
s.add(data[10] < 146)
s.add(filesize ^ data[56] != 246)
s.add(filesize ^ data[32] != 77)
s.add(data[73] > 26)
s.add(data[36] > 11)
s.add(data[70] > 6)
s.add(filesize ^ data[33] != 27)
s.add(data[48] & 128 == 0)
s.add(filesize ^ data[74] != 45)
s.add(data[27] ^ 21 == 40)
s.add(data[60] % 23 < 23)
s.add(filesize ^ data[67] != 63)
s.add(filesize ^ data[0] != 16)
s.add(data[51] % 15 < 15)
s.add(data[50] > 19)
s.add(data[27] < 147)
s.add(filesize ^ data[40] != 230)
s.add(filesize ^ data[2] != 205)
s.add(data[79] % 24 < 24)
s.add(data[69] < 148)
s.add(data[16] & 128 == 0)
s.add(data[61] % 26 < 26)
s.add(data[63] > 31)
s.add(data[14] & 128 == 0)
s.add(data[35] > 1)
s.add(filesize ^ data[11] != 33)
s.add(data[52] < 136)
s.add(data[54] > 15)
s.add(filesize ^ data[20] != 83)
s.add(data[43] > 24)
s.add(data[82] < 152)
s.add((data[59] | (data[59+1] << 8) | (data[59+2] << 16) | (data[59+3] << 24)) ^ 512952669 == 1908304943)
s.add(filesize ^ data[79] != 186)
s.add(filesize ^ data[83] != 197)
s.add(data[39] < 134)
s.add(filesize ^ data[43] != 33)
s.add(data[72] > 10)
s.add(data[83] < 134)
s.add(data[44] % 27 < 27)
s.add(data[40] < 131)
s.add(data[80] % 31 < 31)
s.add(filesize ^ data[47] != 11)
s.add(data[55] % 11 < 11)
s.add(filesize ^ data[71] != 3)
s.add(data[65] - 29 == 70)
s.add(data[58] > 30)
s.add(filesize ^ data[37] != 37)
s.add(data[60] < 130)
s.add(data[27] & 128 == 0)
s.add(data[3] < 141)
s.add(data[73] & 128 == 0)
s.add(filesize ^ data[70] != 209)
s.add(filesize ^ data[2] != 54)
s.add(filesize ^ data[20] != 17)
s.add(data[33] > 18)
s.add(data[37] % 19 < 19)
s.add(filesize ^ data[62] != 15)
s.add(filesize ^ data[10] != 44)
s.add(data[7] % 12 < 12)
s.add(data[71] > 19)
s.add(filesize ^ data[50] != 86)
s.add(data[45] ^ 9 == 104)
s.add(data[8] < 133)
s.add(data[31] < 145)
s.add(data[14] > 20)
s.add(data[54] % 25 < 25)
s.add(filesize ^ data[49] != 156)
s.add(data[47] > 13)
s.add(data[29] > 22)
s.add(data[14] % 19 < 19)
s.add(filesize ^ data[17] != 16)
s.add(filesize ^ data[12] != 226)
s.add(filesize ^ data[65] != 28)
s.add(data[45] & 128 == 0)
s.add(filesize ^ data[6] != 129)
s.add(data[18] % 30 < 30)
s.add(filesize ^ data[62] != 246)
s.add(data[78] % 13 < 13)
s.add(data[36] & 128 == 0)
s.add(data[10] & 128 == 0)
s.add(data[62] > 1)
s.add(data[33] & 128 == 0)
s.add(filesize ^ data[83] != 31)
s.add(data[83] % 21 < 21)
s.add(data[11] > 18)
s.add(data[80] < 143)
s.add(data[81] % 14 < 14)
s.add(data[43] < 160)
s.add(data[1] > 19)
s.add(data[42] % 17 < 17)
s.add(data[44] < 147)
s.add(filesize ^ data[63] != 34)
s.add(filesize ^ data[44] != 17)
s.add((data[28] | (data[28+1] << 8) | (data[28+2] << 16) | (data[28+3] << 24)) - 419186860 == 959764852)
s.add(data[74] + 11 == 116)
s.add(data[48] < 136)
s.add(data[47] < 142)
s.add(data[58] < 146)
s.add(filesize ^ data[71] != 128)
s.add(data[45] < 136)
s.add(data[31] % 17 < 17)
s.add(data[43] & 128 == 0)
s.add(filesize ^ data[43] != 251)
s.add(data[65] > 1)
s.add(data[24] & 128 == 0)
s.add(data[37] < 139)
s.add(filesize ^ data[28] != 238)
s.add(data[78] & 128 == 0)
s.add(filesize ^ data[13] != 219)
s.add(data[19] % 30 < 30)
s.add(filesize ^ data[53] != 243)
s.add(data[81] & 128 == 0)
s.add(data[46] % 28 < 28)
s.add(filesize ^ data[65] != 215)
s.add(filesize ^ data[0] != 41)
s.add(data[84] < 129)
s.add(data[60] & 128 == 0)
s.add(data[20] > 1)
s.add(data[2] % 28 < 28)
s.add(data[58] % 14 < 14)
s.add(data[34] & 128 == 0)
s.add(data[21] & 128 == 0)
s.add(data[84] % 18 < 18)
s.add(data[74] % 10 < 10)
s.add(data[9] < 151)
s.add(data[73] % 23 < 23)
s.add(filesize ^ data[39] != 49)
s.add(data[4] % 17 < 17)
s.add(filesize ^ data[60] != 142)
s.add(filesize ^ data[69] != 30)
s.add(data[30] > 6)
s.add(data[65] & 128 == 0)
s.add(data[39] % 11 < 11)
s.add(data[13] % 27 < 27)
s.add(data[17] % 11 < 11)
s.add(data[56] % 26 < 26)
s.add(data[29] < 157)
s.add(data[57] & 128 == 0)
s.add(filesize ^ data[29] != 37)
s.add(data[77] > 5)
s.add(filesize ^ data[16] != 144)
s.add(data[37] & 128 == 0)
s.add(filesize ^ data[25] != 47)
s.add(data[67] & 128 == 0)
s.add(filesize ^ data[24] != 94)
s.add(data[68] < 138)
s.add(data[57] < 138)
s.add(filesize ^ data[27] != 43)
s.add(filesize ^ data[30] != 18)
s.add(filesize ^ data[59] != 13)
s.add(data[27] % 26 < 26)
s.add(data[56] > 8)
s.add(data[69] & 128 == 0)
s.add(data[18] & 128 == 0)
s.add(data[64] < 154)
s.add(data[76] & 128 == 0)
s.add(data[71] % 28 < 28)
s.add(filesize ^ data[84] != 3)
s.add(filesize ^ data[38] != 84)
s.add(data[32] < 140)
s.add(filesize ^ data[42] != 91)
s.add(data[40] > 15)
s.add(data[27] > 23)
s.add(data[6] % 12 < 12)
s.add(data[10] % 10 < 10)
s.add(data[8] % 21 < 21)
s.add(filesize ^ data[18] != 234)
s.add(data[68] & 128 == 0)
s.add(data[7] < 131)
s.add(data[72] < 134)
s.add(data[16] > 25)
s.add(data[12] % 23 < 23)
s.add(data[41] % 27 < 27)
s.add(data[1] % 17 < 17)
s.add(data[26] > 31)
s.add(data[65] < 149)
s.add(filesize ^ data[51] != 0)
s.add(data[66] > 30)
s.add(filesize ^ data[68] != 8)
s.add(data[25] % 23 < 23)
s.add(data[1] & 128 == 0)
s.add(filesize ^ data[81] != 7)
s.add(data[36] % 22 < 22)
s.add(data[24] < 148)
s.add(data[12] < 147)
s.add(data[74] < 152)
s.add(filesize ^ data[21] != 27)
s.add(filesize ^ data[23] != 18)
s.add(data[38] & 128 == 0)
s.add(data[26] % 25 < 25)
s.add(filesize ^ data[19] != 31)
s.add(data[82] > 3)
s.add(data[5] % 27 < 27)
s.add(data[5] & 128 == 0)
s.add(data[75] - 30 == 86)
s.add(data[54] < 152)
s.add(data[75] < 142)
s.add(data[20] % 28 < 28)
s.add(data[30] & 128 == 0)
s.add((data[66] | (data[66+1] << 8) | (data[66+2] << 16) | (data[66+3] << 24)) ^ 310886682 == 849718389)
s.add(data[64] % 24 < 24)
s.add((data[10] | (data[10+1] << 8) | (data[10+2] << 16) | (data[10+3] << 24)) + 383041523 == 2448764514)
s.add(data[79] & 128 == 0)
s.add(filesize ^ data[59] != 194)
s.add(data[61] & 128 == 0)
s.add(data[70] < 139)
s.add(data[77] & 128 == 0)
s.add(data[13] & 128 == 0)
s.add(data[21] < 138)
s.add(filesize ^ data[46] != 186)
s.add(data[43] % 26 < 26)
s.add(data[61] < 160)
s.add(filesize ^ data[34] != 39)
s.add(data[6] > 6)
s.add(data[35] & 128 == 0)
s.add(data[23] < 141)
s.add(filesize ^ data[82] != 32)
s.add(filesize ^ data[48] != 29)
s.add(data[59] & 128 == 0)
s.add(data[40] % 19 < 19)
s.add(filesize ^ data[39] != 18)
s.add(filesize ^ data[45] != 146)
s.add(data[80] & 128 == 0)
s.add(data[16] < 134)
s.add(data[74] > 1)
s.add(data[23] & 128 == 0)
s.add(data[32] & 128 == 0)
s.add(filesize ^ data[47] != 119)
s.add(filesize ^ data[63] != 135)
s.add(data[64] > 27)
s.add((data[37] | (data[37+1] << 8) | (data[37+2] << 16) | (data[37+3] << 24)) + 367943707 == 1228527996)
s.add(data[82] % 28 < 28)
s.add(data[32] > 28)
s.add(filesize ^ data[24] != 217)
s.add(data[53] < 144)
s.add(data[29] & 128 == 0)
s.add((data[22] | (data[22+1] << 8) | (data[22+2] << 16) | (data[22+3] << 24)) ^ 372102464 == 1879700858)
s.add(data[52] % 23 < 23)
s.add(filesize ^ data[76] != 88)
s.add(filesize ^ data[55] != 17)
s.add(data[26] & 128 == 0)
s.add(data[51] > 7)
s.add(data[12] > 19)
s.add(filesize ^ data[14] != 99)
s.add(filesize ^ data[37] != 141)
s.add(filesize ^ data[14] != 161)
s.add(data[45] % 17 < 17)
s.add(data[33] % 25 < 25)
s.add(filesize ^ data[67] != 55)
s.add(filesize ^ data[53] != 19)
s.add(data[30] < 131)
s.add(data[0] & 128 == 0)
s.add(data[66] & 128 == 0)
s.add(data[41] > 5)
s.add(data[71] & 128 == 0)
s.add(data[29] % 12 < 12)
s.add(data[4] < 139)
s.add(data[77] < 154)
s.add(filesize ^ data[12] != 116)
s.add(data[39] > 7)
s.add(data[75] & 128 == 0)
s.add(data[78] > 24)
s.add(data[69] > 25)
s.add(data[2] + 11 == 119)
s.add(data[15] < 156)
s.add(filesize ^ data[69] != 241)
s.add(filesize ^ data[35] != 18)
s.add(filesize ^ data[17] != 208)
s.add(filesize ^ data[4] != 23)
s.add(data[15] % 16 < 16)
s.add(filesize ^ data[75] != 35)
s.add((data[46] | (data[46+1] << 8) | (data[46+2] << 16) | (data[46+3] << 24)) - 412326611 == 1503714457)
s.add(data[11] % 27 < 27)
s.add(data[83] & 128 == 0)
s.add(filesize ^ data[26] != 161)
s.add(data[49] % 13 < 13)
s.add(filesize ^ data[18] != 33)
s.add(data[6] < 155)
s.add(data[41] < 140)
s.add(filesize ^ data[68] != 135)
s.add(filesize ^ data[9] != 5)
s.add(data[9] & 128 == 0)
s.add(filesize ^ data[36] != 95)
s.add(data[7] > 18)
s.add(filesize ^ data[23] != 242)
s.add(data[62] < 146)
s.add(data[49] & 128 == 0)
s.add(data[62] & 128 == 0)
s.add(data[4] & 128 == 0)
s.add(filesize ^ data[58] != 12)
s.add(data[72] & 128 == 0)
s.add(data[18] > 13)
s.add(filesize ^ data[42] != 1)
s.add(data[59] % 23 < 23)
s.add(data[53] & 128 == 0)
s.add(filesize ^ data[78] != 163)
s.add(data[60] > 14)
s.add(data[47] % 18 < 18)
s.add(data[79] > 31)
s.add(data[22] < 152)
s.add(filesize ^ data[64] != 50)
s.add(filesize ^ data[19] != 222)
s.add(data[81] < 131)
s.add(data[7] - 15 == 82)
s.add(filesize ^ data[51] != 204)
s.add(data[28] > 27)
s.add((data[70] | (data[70+1] << 8) | (data[70+2] << 16) | (data[70+3] << 24)) + 349203301 == 2034162376)
s.add(filesize ^ data[61] != 94)
s.add(data[76] > 2)
s.add(filesize ^ data[77] != 223)
s.add(data[19] > 4)
s.add(data[80] > 2)
s.add(filesize ^ data[35] != 120)
s.add(filesize ^ data[22] != 31)
s.add(data[10] > 9)
s.add(data[22] > 20)
s.add(data[38] < 135)
s.add(filesize ^ data[10] != 205)
s.add(data[25] & 128 == 0)
s.add(data[13] < 147)
s.add(data[42] & 128 == 0)
s.add(filesize ^ data[48] != 99)
s.add(filesize ^ data[16] != 7)
s.add(data[11] < 154)
s.add(filesize ^ data[76] != 30)
s.add(data[30] % 15 < 15)
s.add(filesize ^ data[74] != 193)
s.add(filesize ^ data[52] != 22)
s.add(filesize ^ data[36] != 6)
s.add(data[22] % 22 < 22)
s.add(data[44] & 128 == 0)
s.add(data[50] & 128 == 0)
s.add(filesize ^ data[25] != 224)
s.add(data[15] > 26)
s.add(filesize ^ data[60] != 43)
s.add(data[22] & 128 == 0)
s.add(data[82] & 128 == 0)
s.add((data[80] | (data[80+1] << 8) | (data[80+2] << 16) | (data[80+3] << 24)) - 473886976 == 69677856)
s.add(data[75] > 30)
s.add(data[32] % 17 < 17)
s.add(filesize ^ data[15] != 27)
s.add(data[67] % 16 < 16)
s.add(data[23] > 2)
s.add(data[62] % 13 < 13)
s.add(data[34] < 138)
s.add(filesize ^ data[31] != 32)
s.add(data[72] % 14 < 14)
s.add(filesize ^ data[81] != 242)
s.add(filesize ^ data[54] != 141)
s.add(data[63] & 128 == 0)
s.add(data[0] < 129)
s.add(data[70] % 21 < 21)
s.add(data[8] & 128 == 0)
s.add(data[61] > 12)
s.add(data[24] > 22)
s.add(data[53] % 23 < 23)
s.add(data[46] & 128 == 0)
s.add(data[24] % 26 < 26)
s.add((data[3] | (data[3+1] << 8) | (data[3+2] << 16) | (data[3+3] << 24)) ^ 298697263 == 2108416586)
s.add(data[21] - 21 == 94)
s.add(data[67] < 144)
s.add(data[48] > 15)
s.add(data[37] > 16)
s.add(data[42] < 157)
s.add(data[16] ^ 7 == 115)
s.add(data[13] > 21)
s.add(filesize ^ data[45] != 19)
s.add(data[47] & 128 == 0)
s.add(filesize ^ data[80] != 56)
s.add(filesize ^ data[78] != 6)
s.add(data[76] % 24 < 24)
s.add(data[73] < 136)
s.add(filesize ^ data[52] != 238)
s.add(data[50] % 11 < 11)
s.add(filesize ^ data[7] != 15)
s.add(filesize ^ data[66] != 51)
s.add(data[59] > 4)
s.add(data[46] > 22)
s.add(filesize ^ data[3] != 147)
s.add(data[63] % 30 < 30)
s.add(data[36] < 146)
s.add(data[26] < 132)
s.add(data[6] & 128 == 0)
s.add(filesize ^ data[30] != 249)
s.add((data[41] | (data[41+1] << 8) | (data[41+2] << 16) | (data[41+3] << 24)) + 404880684 == 1699114335)
s.add(filesize ^ data[5] != 243)
s.add(data[70] & 128 == 0)
s.add(data[9] % 22 < 22)
s.add(data[59] < 141)
s.add(filesize ^ data[79] != 104)
s.add(filesize ^ data[5] != 43)
s.add(filesize ^ data[72] != 219)
s.add(data[52] > 25)
s.add(data[74] & 128 == 0)
s.add(data[28] < 160)
s.add(data[51] & 128 == 0)
s.add(data[83] > 16)
s.add(data[31] > 7)
s.add(data[84] & 128 == 0)
s.add(filesize ^ data[46] != 18)
s.add(data[2] > 20)
s.add(data[5] < 158)
s.add(filesize ^ data[32] != 30)
s.add(filesize ^ data[50] != 219)
s.add(data[26] - 7 == 25)
s.add(data[53] > 24)
s.add(data[77] % 24 < 24)
s.add(data[3] % 13 < 13)
s.add(filesize ^ data[9] != 164)
s.add(filesize ^ data[80] != 236)
s.add(data[65] % 22 < 22)
s.add(filesize ^ data[84] != 231)
s.add(filesize ^ data[49] != 10)
s.add(data[67] > 27)
s.add(data[34] % 19 < 19)
s.add(data[64] & 128 == 0)
s.add(filesize ^ data[27] != 244)
s.add(data[12] & 128 == 0)
s.add(data[51] < 139)
s.add(data[35] % 15 < 15)
s.add(data[5] > 14)
s.add(filesize ^ data[34] != 115)
s.add(filesize ^ data[38] != 8)
s.add(filesize ^ data[72] != 37)
s.add(data[20] & 128 == 0)
s.add(data[17] < 150)
s.add(filesize ^ data[70] != 41)
s.add(data[66] % 16 < 16)
s.add(data[17] & 128 == 0)
s.add(data[19] & 128 == 0)
s.add(filesize ^ data[33] != 157)
s.add(data[21] > 7)
s.add(data[58] & 128 == 0)
s.add(data[71] < 130)
s.add(data[41] & 128 == 0)
s.add(data[57] > 11)
s.add(filesize ^ data[8] != 2)
s.add(filesize ^ data[57] != 186)
s.add(data[11] & 128 == 0)
s.add(data[2] < 147)
s.add(data[23] % 16 < 16)
s.add(data[78] < 141)
s.add(data[38] > 18)
s.add(filesize ^ data[41] != 233)
s.add(data[18] < 137)
s.add(data[40] & 128 == 0)
s.add(filesize ^ data[21] != 188)
s.add(filesize ^ data[57] != 14)
s.add(filesize ^ data[4] != 253)
s.add(data[14] < 153)
s.add(data[31] & 128 == 0)
s.add(data[81] > 11)
s.add(data[2] & 128 == 0)
s.add(filesize ^ data[22] != 191)
s.add(data[44] > 5)
s.add(data[84] + 3 == 128)
s.add(data[20] < 135)
s.add(filesize ^ data[73] != 61)
s.add(filesize ^ data[26] != 44)
s.add(data[1] < 158)
s.add(filesize ^ data[29] != 158)
s.add(data[49] < 129)
s.add(filesize ^ data[64] != 158)
s.add(data[25] < 154)
s.add(data[63] < 129)
s.add(data[84] > 26)
s.add(data[39] & 128 == 0)
s.add(data[25] > 27)
s.add(data[49] > 27)
s.add(data[9] > 23)
s.add(filesize ^ data[7] != 221)
s.add(data[50] < 138)
s.add(data[76] < 156)
s.add(filesize ^ data[61] != 239)
s.add(data[57] % 27 < 27)
s.add(filesize ^ data[8] != 107)
s.add(data[79] < 146)
s.add(filesize ^ data[40] != 49)
s.add(data[0] > 30)
s.add(data[45] > 17)
s.add(data[16] % 31 < 31)
s.add(filesize ^ data[1] != 232)
s.add(filesize ^ data[56] != 22)
s.add(data[42] > 3)
s.add(data[52] & 128 == 0)
s.add(data[69] % 30 < 30)
s.add(data[55] < 153)
s.add(filesize ^ data[41] != 74)
s.add(filesize ^ data[1] != 0)
s.add(filesize ^ data[44] != 96)
s.add(filesize ^ data[58] != 77)
s.add(data[34] > 18)
s.add(data[8] > 3)

result = s.check()
print(result)
if (result == sat):
    actual = bytearray()
    for b in data:
        actual.append(s.model()[b].as_long())
    print(actual)